@@ -438,7 +438,7 @@ def upload_process(
         try:
             # TODO:
             more_features = {}
-            features = get_features(more_features, use_ipfs=False)
+            # features = get_features(more_features, use_ipfs=False)
 
             res_ = dtserver_job_heartbeat(
                 token,
@@ -448,7 +448,9 @@ def upload_process(
                 evaluator_version=evaluator_version,
                 impersonate=impersonate,
                 uploaded=_uploaded,
-                features=features,
+                features={},
+                # features=features,
+                query_string=f"phase=upload_process&job_id={job_id}&version={evaluator_version}&machine_id={machine_id}",
             )
         except:
             logger.warning(traceback.format_exc())
@@ -456,46 +458,11 @@ def upload_process(
             if res_["abort"]:
                 break
 
-        time.sleep(random.uniform(10, 15))
+        time.sleep(random.uniform(10, 20))
+
     logger.info("upload_process terminated gracefully")
 
 
-#
-# class TermHandler:
-#     def __init__(self, *, token, job_id, machine_id, process_id, evaluator_version, impersonate, timeout):
-#         self.token = token
-#         self.job_id = job_id
-#         self.machine_id = machine_id
-#         self.process_id = process_id
-#         self.evaluator_version = evaluator_version
-#         self.impersonate = impersonate
-#         self.timeout = timeout
-#
-#     def sigterm_handler(self, _signo, _stack_frame):
-#         s = traceback.format_stack(_stack_frame)
-#         msg_ = f"Evaluator received SIGTERM \n\n{s} "
-#
-#         status = ChallengesConstants.STATUS_JOB_ABORTED
-#         cr0 = ChallengeResults(status, msg_, scores={})
-#         logger.error(cr0=cr0)
-#         dtserver_report_job(
-#             token=self.token,
-#             job_id=self.job_id,
-#             stats=cr0.stats,
-#             result=cr0.get_status(),
-#             ipfs_hashes=cr0.ipfs_hashes,
-#             machine_id=self.machine_id,
-#             process_id=self.process_id,
-#             evaluator_version=self.evaluator_version,
-#             uploaded=[],
-#             impersonate=self.impersonate,
-#             timeout=self.timeout,
-#         )
-#
-#         # Raises SystemExit(0):
-#         sys.exit(23)
-
-
 def go_(
     submission_id_to_ask: Optional[SubmissionID],
     do_pull: bool,
@@ -615,7 +582,8 @@ def go_(
                 evaluator_version=evaluator_version,
                 impersonate=impersonate,
                 uploaded=[],
-                features=features,
+                features={},
+                query_string=f"phase=main&job_id={job_id}&version={evaluator_version}&machine_id={machine_id}",
             )
 
             abort = res_["abort"]
@@ -1156,18 +1124,18 @@ def run_one(
                 color = series[i % len(series)]
                 stream_logs(wd, service_name, service_id, color=color, l=l)
             exited2 = {}
-            heartbeat_interval = 10.0
+            heartbeat_interval = 20.0
             last_heartbeat = 0.0
 
             extra = random.uniform(0, 1)
             while True:
                 time.sleep(5 + extra + random.uniform(0, 1))
 
-                if heartbeat:
+                if heartbeat is not None:
                     t = time.time()
                     if t - last_heartbeat > heartbeat_interval:
                         heartbeat()
-                    last_heartbeat = t
+                        last_heartbeat = t
                 running = []
                 running_details = {}
                 for service_name, container_id in service2id.items():
